Params

Trait Params 

pub trait Params {
    // Required methods
    fn s(&self) -> &Scalar;
    fn k(&self) -> &Scalar;

    // Provided methods
    fn k_inv(&self) -> Scalar { ... }
    fn s_over_k(&self) -> Scalar { ... }
    fn r(&self) -> Scalar { ... }
}
Utilities for the Triple::rsk operation.

Required Methods

fn s(&self) -> &Scalar

Multiply the encrypted plaintext ristretto point by this scalar.

fn k(&self) -> &Scalar

Multiply the target public/private key by this scalar.

Provided Methods

fn k_inv(&self) -> Scalar

Returns 1/k.

fn s_over_k(&self) -> Scalar

Returns s/k.

fn r(&self) -> Scalar

Returns the scalar used for rerandomisation.

Warning: only override this method for the purpose of making deterministic test.

Implementors

Source

impl Params for SAndK<'_, '_>